@@ -19,6 +19,7 @@ from subprocess import Popen, PIPE
 
 from tornado.wsgi import WSGIContainer
 from tornado.ioloop import IOLoop
+from tornado.autoreload import add_reload_hook
 from tornado import web
 from tornado import escape
 from tornado import httputil
@@ -198,7 +199,11 @@ class Server(object):
                        filepath.
         """
         if isinstance(func, string_types):
+            cmd = func
             func = shell(func)
+            func.repr_str = "shell: {}".format(cmd)
+        elif func:
+            func.repr_str = str(func)
 
         self.watcher.watch(filepath, func, delay, ignore=ignore)
 
@@ -219,13 +224,17 @@ class Server(object):
         # The livereload.js snippet.
         # Uses JavaScript to dynamically inject the client's hostname.
         # This allows for serving on 0.0.0.0.
+        live_reload_path = ":{port}/livereload.js?port={port}".format(port=liveport)
+        if liveport == 80 or liveport == 443:
+            live_reload_path = "/livereload.js?port={port}".format(port=liveport)
+
         live_script = escape.utf8((
             '<script type="text/javascript">'
-            'document.write("<script src=''http://"'
-            ' + window.location.hostname + ":{port}/livereload.js''>'
+            'document.write("<script src=''//"'
+            ' + window.location.hostname + "{path}''>'
             ' </"+"script>");'
             '</script>'
-        ).format(port=liveport))
+        ).format(path=live_reload_path))
 
         web_handlers = self.get_web_handlers(live_script)
 
@@ -298,6 +307,7 @@ class Server(object):
         try:
             self.watcher._changes.append(('__livereload__', restart_delay))
             LiveReloadHandler.start_tasks()
+            add_reload_hook(lambda: IOLoop.instance().close(all_fds=True))
             IOLoop.instance().start()
         except KeyboardInterrupt:
             logger.info('Shutting down...')
