@@ -4,4 +4,4 @@ from livereload import Server, shell
 
 server = Server()
 server.watch('docs/*.rst', shell('make html'))
-server.serve(root='docs/_build/html', open_url=True)
+server.serve(root='docs/_build/html', open_url_delay=5)
